/* Bluefish HTML Editor
 * image.h - the thumbnail/multi-thumbnail dialogs
 *
 * Copyright (C) 2001-2010 Olivier Sessink
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __IMAGE_H_
#define __IMAGE_H_

#include "../bluefish.h"

void thumbnail_insert_dialog(Tbfwin * bfwin);
void multi_thumbnail_dialog(Tbfwin * bfwin);

#endif							/* __IMAGE_H_ */
